# filestat
A command line library for file monitoring

## Usages
There is two way to access `filestat` with command line or with `python interpreter`.

`Command Line is under development.`

```python3
>>> # to get file size  
>>> form filestat import utils
>>> utils.get_size('path/to/file.py') # it returns the file size in byte
123121
>>> 
``` 

`The program is still under development`